@@ -61,20 +61,6 @@
 
 static DisplayInfo *default_display;
 
-static int
-handleXError (Display * dpy, XErrorEvent * err)
-{
-#if DEBUG
-    char buf[64];
-
-    XGetErrorText (dpy, err->error_code, buf, 63);
-    fprintf (stderr, "XError: %s\n", buf);
-    fprintf (stderr, "==>  XID 0x%lx, request code %d, serial %lu, error code %d, minor code %d <==\n",
-              err->resourceid, err->request_code, err->serial, err->error_code, err->minor_code);
-#endif
-    return 0;
-}
-
 static gboolean
 myDisplayInitAtoms (DisplayInfo *display_info)
 {
@@ -83,7 +69,6 @@ myDisplayInitAtoms (DisplayInfo *display_info)
         "_GTK_FRAME_EXTENTS",
         "_GTK_HIDE_TITLEBAR_WHEN_MAXIMIZED",
         "_GTK_SHOW_WINDOW_MENU",
-        "_KDE_NET_WM_SYSTEM_TRAY_WINDOW_FOR",
         "KWM_WIN_ICON",
         "_MOTIF_WM_HINTS",
         "_MOTIF_WM_INFO",
@@ -104,7 +89,6 @@ myDisplayInitAtoms (DisplayInfo *display_info)
         "_NET_STARTUP_ID",
         "_NET_SUPPORTED",
         "_NET_SUPPORTING_WM_CHECK",
-        "_NET_SYSTEM_TRAY_OPCODE",
         "_NET_WM_ACTION_ABOVE",
         "_NET_WM_ACTION_BELOW",
         "_NET_WM_ACTION_CHANGE_DESKTOP",
@@ -227,8 +211,6 @@ myDisplayInit (GdkDisplay *gdisplay)
     display->quit = FALSE;
     display->reload = FALSE;
 
-    XSetErrorHandler (handleXError);
-
     /* Initialize internal atoms */
     if (!myDisplayInitAtoms (display))
     {
@@ -728,29 +710,6 @@ myDisplayGetScreenFromWindow (DisplayInfo *display, Window w)
     return NULL;
 }
 
-#ifdef ENABLE_KDE_SYSTRAY_PROXY
-ScreenInfo *
-myDisplayGetScreenFromSystray (DisplayInfo *display, Window w)
-{
-    GSList *list;
-
-    g_return_val_if_fail (w != None, NULL);
-    g_return_val_if_fail (display != NULL, NULL);
-
-    for (list = display->screens; list; list = g_slist_next (list))
-    {
-        ScreenInfo *screen = (ScreenInfo *) list->data;
-        if (screen->systray == w)
-        {
-            return screen;
-        }
-    }
-    TRACE ("no screen found");
-
-    return NULL;
-}
-#endif /* ENABLE_KDE_SYSTRAY_PROXY */
-
 #ifdef HAVE_XSYNC
 Client *
 myDisplayGetClientFromXSyncAlarm (DisplayInfo *display, XSyncAlarm xalarm)
@@ -1055,49 +1014,29 @@ myDisplayTestXrender (DisplayInfo *display, gdouble min_time)
 void
 myDisplayErrorTrapPush (DisplayInfo *display_info)
 {
-#if GTK_CHECK_VERSION(3, 22, 0)
     gdk_x11_display_error_trap_push (display_info->gdisplay);
-#else
-    gdk_error_trap_push ();
-#endif
 }
 
 gint
 myDisplayErrorTrapPop (DisplayInfo *display_info)
 {
-#if GTK_CHECK_VERSION(3, 22, 0)
     return gdk_x11_display_error_trap_pop (display_info->gdisplay);
-#else
-    return gdk_error_trap_pop ();
-#endif
 }
 
 void
 myDisplayErrorTrapPopIgnored (DisplayInfo *display_info)
 {
-#if GTK_CHECK_VERSION(3, 22, 0)
     gdk_x11_display_error_trap_pop_ignored (display_info->gdisplay);
-#else
-    gdk_error_trap_pop_ignored ();
-#endif
 }
 
 void
 myDisplayBeep (DisplayInfo *display_info)
 {
-#if GTK_CHECK_VERSION(3, 22, 0)
     gdk_display_beep (display_info->gdisplay);;
-#else
-    gdk_beep ();
-#endif
 }
 
 GdkKeymap *
 myDisplayGetKeymap (DisplayInfo *display_info)
 {
-#if GTK_CHECK_VERSION(3, 22, 0)
     return gdk_keymap_get_for_display (display_info->gdisplay);
-#else
-    return gdk_keymap_get_default ();
-#endif
 }
