@@ -147,7 +147,7 @@ typeOfClick_end (gpointer data)
 
     gtk_main_quit ();
 
-    return (FALSE);
+    return FALSE;
 }
 
 static eventFilterStatus
@@ -645,9 +645,6 @@ edgeGetPart (Client *c, XfwmEventButton *event)
     x_distance = c->width / 2 - abs(c->width / 2 - event->x);
     y_distance = c->height / 2 - abs(c->height / 2 - event->y);
 
-    /* Set a sensible default value */
-    part = CORNER_BOTTOM_RIGHT;
-
     if (x_distance < x_corner_pixels && y_distance < y_corner_pixels)
     {
         /* In a corner */
@@ -1107,22 +1104,9 @@ handleDestroyNotify (DisplayInfo *display_info, XDestroyWindowEvent * ev)
     GList *list_of_windows;
     Client *c;
 
-#ifdef ENABLE_KDE_SYSTRAY_PROXY
-    ScreenInfo *screen_info;
-#endif
-
     TRACE ("window (0x%lx)", ev->window);
 
     status = EVENT_FILTER_PASS;
-#ifdef ENABLE_KDE_SYSTRAY_PROXY
-    screen_info = myDisplayGetScreenFromSystray (display_info, ev->window);
-    if (screen_info)
-    {
-        /* systray window is gone */
-        screen_info->systray = None;
-        return EVENT_FILTER_REMOVE;
-    }
-#endif
 
     c = myDisplayGetClientFromWindow (display_info, ev->window, SEARCH_WINDOW);
     if (c)
@@ -1161,7 +1145,6 @@ handleMapRequest (DisplayInfo *display_info, XMapRequestEvent * ev)
         if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MAP_PENDING))
         {
             TRACE ("ignoring MapRequest on window (0x%lx)", ev->window);
-            status = EVENT_FILTER_REMOVE;
         }
 
         if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_WAS_SHOWN))
@@ -1175,14 +1158,13 @@ handleMapRequest (DisplayInfo *display_info, XMapRequestEvent * ev)
         {
             clientFocusNew(c);
         }
-        status = EVENT_FILTER_REMOVE;
     }
     else
     {
         clientFrame (display_info, ev->window, FALSE);
-        status = EVENT_FILTER_REMOVE;
     }
 
+    status = EVENT_FILTER_REMOVE;
     return status;
 }
 
@@ -1912,7 +1894,6 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
     if (c)
     {
         status = EVENT_FILTER_REMOVE;
-        screen_info = c->screen_info;
 
         if ((ev->message_type == display_info->atoms[WM_CHANGE_STATE]) && (ev->format == 32) && (ev->data.l[0] == IconicState))
         {
@@ -2021,14 +2002,6 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
 
             TRACE ("window (0x%lx) has received a MANAGER event", ev->window);
             selection = (Atom) ev->data.l[1];
-#ifdef ENABLE_KDE_SYSTRAY_PROXY
-            if (selection == screen_info->net_system_tray_selection)
-            {
-                TRACE ("root has received a NET_SYSTEM_TRAY_MANAGER selection event");
-                screen_info->systray = getSystrayWindow (display_info, screen_info->net_system_tray_selection);
-            }
-            else
-#endif
             if (myScreenCheckWMAtom (screen_info, selection))
             {
                 TRACE ("root has received a WM_Sn selection event");
@@ -2388,7 +2361,6 @@ menu_callback (Menu * menu, MenuOp op, Window xid, gpointer menu_data, gpointer
                 clientToggleShaded (c);
                 break;
             case MENU_OP_STICK:
-            case MENU_OP_UNSTICK:
                 clientToggleSticky (c, TRUE);
                 frameQueueDraw (c, FALSE);
                 break;
@@ -2514,11 +2486,7 @@ show_window_menu (Client *c, gint px, gint py, guint button, guint32 timestamp,
         ops |= MENU_OP_SHADE;
     }
 
-    if (FLAG_TEST (c->flags, CLIENT_FLAG_STICKY))
-    {
-        ops |= MENU_OP_UNSTICK;
-    }
-    else
+    if (!FLAG_TEST (c->flags, CLIENT_FLAG_STICKY))
     {
         ops |= MENU_OP_STICK;
     }
@@ -2536,7 +2504,7 @@ show_window_menu (Client *c, gint px, gint py, guint button, guint32 timestamp,
 
     if (is_transient || !FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_STICK))
     {
-        insensitive |= MENU_OP_STICK | MENU_OP_UNSTICK;
+        insensitive |= MENU_OP_STICK;
     }
 
     if (!CLIENT_CAN_HIDE_WINDOW (c))
@@ -2666,7 +2634,7 @@ show_popup_cb (GtkWidget * widget, GdkEventButton * ev, gpointer data)
 
     show_window_menu ((Client *) data, (gint) ev->x_root, (gint) ev->y_root, ev->button, ev->time, FALSE);
 
-    return (TRUE);
+    return TRUE;
 }
 
 static gboolean
@@ -2675,7 +2643,7 @@ set_reload (DisplayInfo *display_info)
     TRACE ("setting reload flag so all prefs will be reread at next event loop");
 
     display_info->reload = TRUE;
-    return (TRUE);
+    return TRUE;
 }
 
 static gboolean
@@ -2693,7 +2661,7 @@ double_click_time_cb (GObject * obj, GdkEvent * ev, gpointer data)
         display_info->double_click_time = abs (g_value_get_int (&tmp_val));
     }
 
-    return (TRUE);
+    return TRUE;
 }
 
 static gboolean
@@ -2711,7 +2679,7 @@ double_click_distance_cb (GObject * obj, GdkEvent * ev, gpointer data)
         display_info->double_click_distance = abs (g_value_get_int (&tmp_val));
     }
 
-    return (TRUE);
+    return TRUE;
 }
 
 static void
@@ -2755,7 +2723,7 @@ refresh_font_cb (GObject * obj, GdkEvent * ev, gpointer data)
         update_screen_font (list->data);
     }
 
-    return (TRUE);
+    return TRUE;
 }
 
 /*
