@@ -48,35 +48,35 @@ enum
 
 static GtkWidget *menu_open = NULL;
 static MenuItem menuitems[] = {
-    {MENU_OP_MAXIMIZE,     N_("Ma_ximize")},
-    {MENU_OP_UNMAXIMIZE,   N_("Unma_ximize")},
-    {MENU_OP_MINIMIZE,     N_("Mi_nimize")},
-    {MENU_OP_MINIMIZE_ALL, N_("Minimize _Other Windows")},
-    {MENU_OP_UNMINIMIZE,   N_("S_how")},
-    {MENU_OP_MOVE,         N_("_Move")},
-    {MENU_OP_RESIZE,       N_("_Resize")},
-    {0, NULL}, /* -------------------------------------------------------- */
-    {MENU_OP_ABOVE,        N_("Always on _Top")},
-    {MENU_OP_NORMAL,       N_("_Same as Other Windows")},
-    {MENU_OP_BELOW,        N_("Always _Below Other Windows")},
-    {MENU_OP_SHADE,        N_("Roll Window Up")},
-    {MENU_OP_UNSHADE,      N_("Roll Window Down")},
-    {MENU_OP_FULLSCREEN,   N_("_Fullscreen")},
-    {MENU_OP_UNFULLSCREEN, N_("Leave _Fullscreen")},
-    {MENU_OP_CONTEXT_HELP, N_("Context _Help")},
-    {0, NULL}, /* -------------------------------------------------------- */
-    {MENU_OP_STICK,        N_("Always on _Visible Workspace")},
-    {MENU_OP_UNSTICK,      N_("Only _Visible on This Workspace")},
-    {MENU_OP_WORKSPACES,   N_("Move to Another _Workspace")},
-    {0, NULL}, /* -------------------------------------------------------- */
-    {MENU_OP_DELETE,       N_("_Close")},
+    {MENU_OP_MAXIMIZE,     MENU_TYPE_REGULAR,  N_("Ma_ximize")},
+    {MENU_OP_UNMAXIMIZE,   MENU_TYPE_REGULAR,  N_("Unma_ximize")},
+    {MENU_OP_MINIMIZE,     MENU_TYPE_REGULAR,  N_("Mi_nimize")},
+    {MENU_OP_MINIMIZE_ALL, MENU_TYPE_REGULAR,  N_("Minimize _Other Windows")},
+    {MENU_OP_UNMINIMIZE,   MENU_TYPE_REGULAR,  N_("S_how")},
+    {MENU_OP_MOVE,         MENU_TYPE_REGULAR,  N_("_Move")},
+    {MENU_OP_RESIZE,       MENU_TYPE_REGULAR,  N_("_Resize")},
+    {0, 0, NULL}, /* ----------------------------------------------*/
+    {MENU_OP_ABOVE,        MENU_TYPE_RADIO,    N_("Always on _Top")},
+    {MENU_OP_NORMAL,       MENU_TYPE_RADIO,    N_("_Same as Other Windows")},
+    {MENU_OP_BELOW,        MENU_TYPE_RADIO,    N_("Always _Below Other Windows")},
+    {0, 0, NULL}, /* ----------------------------------------------*/
+    {MENU_OP_SHADE,        MENU_TYPE_REGULAR,  N_("Roll Window Up")},
+    {MENU_OP_UNSHADE,      MENU_TYPE_REGULAR,  N_("Roll Window Down")},
+    {MENU_OP_FULLSCREEN,   MENU_TYPE_REGULAR,  N_("_Fullscreen")},
+    {MENU_OP_UNFULLSCREEN, MENU_TYPE_REGULAR,  N_("Leave _Fullscreen")},
+    {MENU_OP_CONTEXT_HELP, MENU_TYPE_REGULAR,  N_("Context _Help")},
+    {0, 0, NULL}, /* ----------------------------------------------*/
+    {MENU_OP_STICK,        MENU_TYPE_CHECKBOX, N_("Always on _Visible Workspace")},
+    {MENU_OP_WORKSPACES,   MENU_TYPE_REGULAR,  N_("Move to Another _Workspace")},
+    {0, 0, NULL}, /* ----------------------------------------------*/
+    {MENU_OP_DELETE,       MENU_TYPE_REGULAR,  N_("_Close")},
 #if 0
     {0, NULL, NULL}, /* -------------------------------------------------------- */
     {MENU_OP_DESTROY,      N_("Destroy")},
     {0, NULL, NULL}, /* -------------------------------------------------------- */
 #endif
-    {MENU_OP_QUIT,         N_("_Quit")},
-    {MENU_OP_RESTART,      N_("Restart")},
+    {MENU_OP_QUIT,         MENU_TYPE_REGULAR, N_("_Quit")},
+    {MENU_OP_RESTART,      MENU_TYPE_REGULAR, N_("Restart")},
 };
 
 static eventFilterStatus
@@ -112,7 +112,7 @@ activate_cb (GtkWidget * menuitem, gpointer data)
                              menudata->menu->xid,
                              menudata->menu->data,
                              menudata->data);
-    return (FALSE);
+    return FALSE;
 }
 
 static gboolean
@@ -127,7 +127,7 @@ menu_closed (GtkMenu * widget, gpointer data)
 
     eventFilterPop (menu->filter_setup);
     (*menu->func) (menu, 0, menu->xid, menu->data, NULL);
-    return (FALSE);
+    return FALSE;
 }
 
 static GtkWidget *
@@ -215,7 +215,7 @@ menu_default (GdkScreen *gscr, Window xid, MenuOp ops, MenuOp insensitive, MenuF
     i = 0;
     while (i < (int) (sizeof (menuitems) / sizeof (MenuItem)))
     {
-        if ((ops & menuitems[i].op) || (menuitems[i].op == MENU_OP_SEPARATOR))
+        if ((ops & menuitems[i].op) || (menuitems[i].type != MENU_TYPE_REGULAR))
         {
             label = _(menuitems[i].label);
             ws_menu = NULL;
@@ -235,7 +235,22 @@ menu_default (GdkScreen *gscr, Window xid, MenuOp ops, MenuOp insensitive, MenuF
                     g_signal_connect (G_OBJECT (ws_menu), "selection-done", G_CALLBACK (menu_closed), menu);
                     break;
                 default:
-                    menuitem = gtk_menu_item_new_with_mnemonic (label);
+                    switch (menuitems[i].type)
+                    {
+                        case MENU_TYPE_RADIO:
+                            menuitem = gtk_check_menu_item_new_with_mnemonic (label);
+                            gtk_check_menu_item_set_draw_as_radio (GTK_CHECK_MENU_ITEM (menuitem), TRUE);
+                            /* Set item as checked if it is *not* a valid op. This is because it is already checked and cannot be reselected */
+                            gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), !(ops & menuitems[i].op));
+                            break;
+                        case MENU_TYPE_CHECKBOX:
+                            menuitem = gtk_check_menu_item_new_with_mnemonic (label);
+                            /* Set item as checked if it is *not* a valid op. This is because it is already checked and cannot be reselected */
+                            gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), !(ops & menuitems[i].op));
+                            break;
+                        default:
+                            menuitem = gtk_menu_item_new_with_mnemonic (label);
+                    }
                     if (insensitive & menuitems[i].op)
                     {
                         gtk_widget_set_sensitive (menuitem, FALSE);
@@ -298,105 +313,9 @@ menu_check_and_close (void)
         TRACE ("emitting deactivate signal");
         g_signal_emit_by_name (G_OBJECT (menu_open), "deactivate");
         menu_open = NULL;
-        return (TRUE);
+        return TRUE;
     }
-    return (FALSE);
-}
-
-static GdkDevice *
-menu_get_device (GdkWindow *win, gint grab_device_type)
-{
-    GdkDisplay *display;
-    GdkSeat *seat;
-
-    display = gdk_window_get_display (win);
-    seat = gdk_display_get_default_seat (display);
-
-    switch (grab_device_type)
-    {
-        case GRAB_DEVICE_POINTER:
-            return gdk_seat_get_pointer (seat);
-        case GRAB_DEVICE_KEYBOARD:
-            return gdk_seat_get_keyboard (seat);
-        default:
-            return NULL;
-    }
-}
-
-static GdkGrabStatus
-menu_device_grab (GdkWindow *win, gint grab_device_type, GdkEventMask event_mask, guint32 timestamp)
-{
-    GdkDevice *device;
-
-    device = menu_get_device (win, grab_device_type);
-
-    g_return_val_if_fail (device != NULL, GDK_GRAB_FAILED);
-
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-    return gdk_device_grab (device, win, GDK_OWNERSHIP_NONE, TRUE, event_mask, NULL, timestamp);
-G_GNUC_END_IGNORE_DEPRECATIONS
-}
-
-static void
-menu_device_ungrab (GdkWindow *win, gint grab_device_type, guint32 timestamp)
-{
-    GdkDevice *device;
-
-    device = menu_get_device (win, grab_device_type);
-
-    g_return_if_fail (device != NULL);
-
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-    gdk_device_ungrab (device, timestamp);
-G_GNUC_END_IGNORE_DEPRECATIONS
-}
-
-static gboolean
-grab_available (GdkWindow *win, guint32 timestamp)
-{
-    GdkEventMask pointer_mask;
-    GdkEventMask keyboard_mask;
-    GdkGrabStatus g1;
-    GdkGrabStatus g2;
-    gboolean grab_failed;
-    gint i;
-
-    TRACE ("entering");
-
-    pointer_mask = GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
-                   GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
-                   GDK_POINTER_MOTION_MASK;
-    keyboard_mask = GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK;
-    g1 = menu_device_grab (win, GRAB_DEVICE_POINTER, pointer_mask, timestamp);
-    g2 = menu_device_grab (win, GRAB_DEVICE_KEYBOARD, keyboard_mask, timestamp);
-    grab_failed = FALSE;
-
-    i = 0;
-    while ((i++ < 100) && (grab_failed = ((g1 != GDK_GRAB_SUCCESS)
-                || (g2 != GDK_GRAB_SUCCESS))))
-    {
-        TRACE ("grab not available yet, waiting... (%i)", i);
-        g_usleep (100);
-        if (g1 != GDK_GRAB_SUCCESS)
-        {
-            g1 = menu_device_grab (win, GRAB_DEVICE_POINTER, pointer_mask, timestamp);
-        }
-        if (g2 != GDK_GRAB_SUCCESS)
-        {
-            g2 = menu_device_grab (win, GRAB_DEVICE_KEYBOARD, keyboard_mask, timestamp);
-        }
-    }
-
-    if (g1 == GDK_GRAB_SUCCESS)
-    {
-        menu_device_ungrab (win, GRAB_DEVICE_POINTER, timestamp);
-    }
-    if (g2 == GDK_GRAB_SUCCESS)
-    {
-        menu_device_ungrab (win, GRAB_DEVICE_KEYBOARD, timestamp);
-    }
-
-    return (!grab_failed);
+    return FALSE;
 }
 
 static GdkEvent *
@@ -438,7 +357,6 @@ menu_popup_event (Menu *menu, gint root_x, gint root_y, guint button, guint32 ti
 gboolean
 menu_popup (Menu *menu, gint root_x, gint root_y, guint button, guint32 timestamp)
 {
-    GdkPoint *pt;
     GdkWindow *window;
     GdkEvent *event;
     GdkRectangle rectangle;
@@ -447,20 +365,10 @@ menu_popup (Menu *menu, gint root_x, gint root_y, guint button, guint32 timestam
     g_return_val_if_fail (GTK_IS_MENU (menu->menu), FALSE);
     TRACE ("entering");
 
-    pt = g_new0 (GdkPoint, 1);
-    pt->x = root_x;
-    pt->y = root_y;
-
     window = gdk_screen_get_root_window (menu->screen);
 
     if (!menu_check_and_close ())
     {
-        if (!grab_available (window, timestamp))
-        {
-            g_free (pt);
-            TRACE ("cannot get grab on pointer/keyboard, cancel.");
-            return FALSE;
-        }
         TRACE ("opening new menu");
         menu_open = menu->menu;
         eventFilterPush (menu->filter_setup, menu_filter, NULL);
