@@ -16,7 +16,7 @@
         MA 02110-1301, USA.
 
 
-        xfwm4    - (c) 2002-2015 Olivier Fourdan
+        xfwm4    - (c) 2002-2021 Olivier Fourdan
 
  */
 
@@ -33,6 +33,8 @@
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h>
 
+#include <common/xfwm-common.h>
+
 #include "client.h"
 #include "moveresize.h"
 #include "compositor.h"
@@ -334,7 +336,6 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
     action = ev->data.l[0];
     first  = ev->data.l[1];
     second = ev->data.l[2];
-    mode = 0;
 
     if ((first  == display_info->atoms[NET_WM_STATE_HIDDEN]) ||
         (second == display_info->atoms[NET_WM_STATE_HIDDEN]))
@@ -649,7 +650,6 @@ clientNetMoveResize (Client * c, XClientMessageEvent * ev)
     }
 
     corner = CORNER_BOTTOM_RIGHT;
-    resize = TRUE;
 
     xevent->xbutton.button = button;
     xevent->xbutton.x_root = xevent->xkey.x_root = x_root;
@@ -721,7 +721,6 @@ clientNetMoveResize (Client * c, XClientMessageEvent * ev)
             FALLTHROUGH;
         default: /* Do nothing */
             return;
-            break;
     }
 
     if (!FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN))
@@ -1497,7 +1496,7 @@ ping_timeout_cb (gpointer data)
         TRACE ("ping timeout on client \"%s\"", c->name);
         terminateShowDialog (c);
     }
-    return (FALSE);
+    return FALSE;
 }
 
 void
@@ -1547,7 +1546,7 @@ clientSendNetWMPing (Client *c, guint32 timestamp)
 
     if (!FLAG_TEST (c->wm_flags, WM_FLAG_PING))
     {
-        return (FALSE);
+        return FALSE;
     }
 
     clientRemoveNetWMPing (c);
@@ -1555,6 +1554,12 @@ clientSendNetWMPing (Client *c, guint32 timestamp)
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
 
+    /* Working around GDK bugs (multi-screen has been removed from GDK a while ago) */
+    if (!xfwm_is_default_screen (screen_info->gscr))
+    {
+        return FALSE;
+    }
+
     /* Makes sure the timestamp is meaningfull */
     c->ping_time = myDisplayGetTime (display_info, timestamp);
     g_return_val_if_fail (timestamp != CurrentTime, FALSE);
@@ -1564,7 +1569,7 @@ clientSendNetWMPing (Client *c, guint32 timestamp)
         g_timeout_add_full (G_PRIORITY_DEFAULT,
                             CLIENT_PING_TIMEOUT,
                             ping_timeout_cb, c, NULL);
-    return (TRUE);
+    return TRUE;
 }
 
 gboolean
