@@ -35,12 +35,18 @@
 #define CLIENT_CONSTRAINED_LEFT    1<<2
 #define CLIENT_CONSTRAINED_RIGHT   1<<3
 
-void                     clientMaxSpace                         (ScreenInfo *,
+gboolean                 strutsToRectangles                     (Client *,
+                                                                 GdkRectangle * /* left */,
+                                                                 GdkRectangle * /* right */,
+                                                                 GdkRectangle * /* top */,
+                                                                 GdkRectangle * /* bottom */);
+void                     clientMaxSpace                         (Client *,
                                                                  int *,
                                                                  int *,
                                                                  int *,
                                                                  int *);
-gboolean                 clientCheckTitle                       (Client *);
+gboolean                 clientsHaveOverlap                     (Client *,
+                                                                 Client *);
 unsigned int             clientConstrainPos                     (Client *,
                                                                  gboolean);
 void                     clientInitPosition                     (Client *);
