@@ -169,12 +169,6 @@ struct _ScreenInfo
     gboolean tabwin_provider_ready;
     GtkCssProvider *tabwin_provider;
 
-#ifdef ENABLE_KDE_SYSTRAY_PROXY
-    /* There can be one systray per screen */
-    Atom net_system_tray_selection;
-    Window systray;
-#endif
-
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
     /* Startup notification data, per screen */
     SnMonitorContext *sn_context;
@@ -234,6 +228,7 @@ struct _ScreenInfo
     gboolean texture_inverted;
     gboolean has_mesa_swap_control;
     gboolean has_ext_swap_control;
+    gboolean has_ext_swap_control_tear;
     gboolean has_ext_arb_sync;
 
     GLuint rootTexture;
